==> phoenix_widgets-1.11.1.tar.gz: example/lib/phoenix_card_page.dart <==
import 'package:flutter/material.dart';
import 'package:phoenix_widgets/phoenix_widgets.dart';

class PhoenixCardPage extends StatefulWidget {
  const PhoenixCardPage({Key? key}) : super(key: key);

  @override
  State<PhoenixCardPage> createState() => _PhoenixCardPageState();
}

class _PhoenixCardPageState extends State<PhoenixCardPage> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: Colors.white,
        appBar: AppBar(
          title: const Text('Phoenix Card Sample App'),
        ),
        body: Column(
          children: [
            PhoenixCard(
              title: Text(
                "Title with Image",
                style: Theme.of(context).textTheme.headline6,
              ),
              description: Text(
                "Description",
                style: Theme.of(context).textTheme.bodyText2,
              ),
              footer: Row(
                mainAxisAlignment: MainAxisAlignment.start,
                children: [
                  const CircleAvatar(backgroundColor: Colors.red),
                  const SizedBox(width: 8),
                  Text(
                    "Footer",
                    style: Theme.of(context).textTheme.headline6,
                  )
                ],
              ),
              image: Image.network(
                "https://images.contentstack.io/v3/assets/blt2a130c768c36b9df/blt5f384c7eb51e7cff/5f7d972ddf178b0ea98488e1/banner_sadaqah.jpg?auto=webp",
                fit: BoxFit.cover,
              ),
              onTap: () {},
            ),
            PhoenixCard(
              title: Text(
                "Title without Image",
                style: Theme.of(context).textTheme.headline6,
              ),
              description: Text(
                "Description",
                style: Theme.of(context).textTheme.bodyText2,
              ),
              footer: Row(
                mainAxisAlignment: MainAxisAlignment.start,
                children: [
                  const CircleAvatar(backgroundColor: Colors.red),
                  const SizedBox(width: 8),
                  Text(
                    "Footer",
                    style: Theme.of(context).textTheme.headline6,
                  )
                ],
              ),
              onTap: () {},
            ),
            PhoenixCard(
              title: Text(
                "Title without Image and Footer",
                style: Theme.of(context).textTheme.headline6,
              ),
              description: Text(
                "Description",
                style: Theme.of(context).textTheme.bodyText2,
              ),
              onTap: () {},
            ),
          ],
        ));
  }
}

==> phoenix_widgets-1.17.4.tar.gz: example/lib/phoenix_card_page.dart <==
import 'package:flutter/material.dart';
import 'package:phoenix_widgets/phoenix_widgets.dart';

class PhoenixCardPage extends StatefulWidget {
  const PhoenixCardPage({Key? key}) : super(key: key);

  @override
  State<PhoenixCardPage> createState() => _PhoenixCardPageState();
}

class _PhoenixCardPageState extends State<PhoenixCardPage> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: Colors.white,
        appBar: AppBar(
          title: const Text('Phoenix Card Sample App'),
        ),
        body: Column(
          children: [
            PhoenixCard(
              title: Text(
                "Title with Image",
                style: Theme.of(context).textTheme.titleLarge,
              ),
              description: Text(
                "Description",
                style: Theme.of(context).textTheme.bodyMedium,
              ),
              footer: Row(
                mainAxisAlignment: MainAxisAlignment.start,
                children: [
                  const CircleAvatar(backgroundColor: Colors.red),
                  const SizedBox(width: 8),
                  Text(
                    "Footer",
                    style: Theme.of(context).textTheme.titleLarge,
                  )
                ],
              ),
              image: Image.network(
                "https://images.contentstack.io/v3/assets/blt2a130c768c36b9df/blt5f384c7eb51e7cff/5f7d972ddf178b0ea98488e1/banner_sadaqah.jpg?auto=webp",
                fit: BoxFit.cover,
              ),
              onTap: () {},
            ),
            PhoenixCard(
              title: Text(
                "Title without Image",
                style: Theme.of(context).textTheme.titleLarge,
              ),
              description: Text(
                "Description",
                style: Theme.of(context).textTheme.bodyMedium,
              ),
              footer: Row(
                mainAxisAlignment: MainAxisAlignment.start,
                children: [
                  const CircleAvatar(backgroundColor: Colors.red),
                  const SizedBox(width: 8),
                  Text(
                    "Footer",
                    style: Theme.of(context).textTheme.titleLarge,
                  )
                ],
              ),
              onTap: () {},
            ),
            PhoenixCard(
              title: Text(
                "Title without Image and Footer",
                style: Theme.of(context).textTheme.titleLarge,
              ),
              description: Text(
                "Description",
                style: Theme.of(context).textTheme.bodyMedium,
              ),
              onTap: () {},
            ),
          ],
        ));
  }
}
